<?php

/**
 * Theme settings
 *
 * @param array $settings
 * @return array
 */
function theme_app_settings($settings) {
    return json_decode(<<<JSON
    {
    "colorScheme": {
        "bodyColors": [
            "#111111",
            "#ffffff"
        ],
        "bgColor": "#ffffff",
        "colors": [
            "#79a14e",
            "#346473",
            "#a3de83",
            "#f7d79a",
            "#f7f39a"
        ],
        "customColors": [
            "#b43737",
            "#3a6877",
            "#ab4f4d",
            "#f8fcfd",
            "#5b2f00",
            "#8c4b29",
            "#bd9a60",
            "#9f684c",
            "#d0b489",
            "#292929"
        ],
        "shadingContrast": "body-alt-color",
        "whiteContrast": "body-color",
        "bgContrast": "body-color",
        "name": "u10"
    },
    "fontScheme": {
        "name": "custom-font-family-1",
        "default": true,
        "fonts": {
            "heading": "Alex Brush",
            "text": "Open Sans, sans-serif",
            "accent": "Arial, sans-serif",
            "headingTitle": "Alex Brush",
            "textTitle": "Open Sans"
        }
    },
    "typography": {
        "name": "custom-page-typography-3",
        "title": {
            "font-weight": "300",
            "line-height": "1_1",
            "font-size": 4.5,
            "margin-top": 20,
            "margin-bottom": 20
        },
        "subtitle": {
            "font-weight": "300",
            "line-height": "1_2",
            "font-size": 2.25,
            "margin-top": 20,
            "margin-bottom": 20,
            "font": "text-font"
        },
        "h1": {
            "line-height": "1_1",
            "font-size": 4.5,
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "400"
        },
        "h2": {
            "line-height": "1_2",
            "font-size": 3,
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "400"
        },
        "h3": {
            "line-height": "1_2",
            "font-size": 2.25,
            "margin-top": 20,
            "margin-bottom": 20,
            "font": "text-font",
            "font-weight": "500"
        },
        "h4": {
            "font-weight": "300",
            "line-height": "1_2",
            "font-size": 1.5,
            "margin-top": 20,
            "margin-bottom": 20,
            "font": "text-font"
        },
        "h5": {
            "font-weight": "300",
            "line-height": "1_2",
            "font-size": 1.25,
            "margin-top": 20,
            "margin-bottom": 20,
            "font": "text-font"
        },
        "h6": {
            "font-weight": "300",
            "line-height": "1_2",
            "font-size": 1.125,
            "margin-top": 20,
            "margin-bottom": 20,
            "font": "text-font"
        },
        "largeText": {
            "bold": false,
            "line-height": "1_6",
            "font-size": 1,
            "margin-top": 20,
            "margin-bottom": 20
        },
        "text": {
            "bold": false,
            "line-height": "1_6",
            "font-size": 1,
            "margin-top": 20,
            "margin-bottom": 20
        },
        "smallText": {
            "bold": false,
            "line-height": "1_6",
            "font-size": 0.875,
            "margin-top": 20,
            "margin-bottom": 20
        },
        "link": {},
        "button": {
            "letter-spacing": 2,
            "font-size": 1.125,
            "line-height": "1_4",
            "color": "palette-1-base",
            "margin-top": 20,
            "margin-bottom": 20,
            "text-transform": "uppercase"
        },
        "blockquote": {
            "font-style": "italic",
            "line-height": "1_6",
            "font-size": 1.25,
            "indent": 20,
            "border": 4,
            "border-color": "palette-1-base",
            "margin-top": 20,
            "margin-bottom": 20
        },
        "metadata": {
            "font-size": 0.75,
            "letter-spacing": "1",
            "line-height": "1_4",
            "margin-top": 20,
            "margin-bottom": 20
        },
        "list": {
            "margin-top": 20,
            "margin-bottom": 20
        },
        "orderedlist": {
            "margin-top": 20,
            "margin-bottom": 20
        },
        "postContent": {
            "margin-top": 20,
            "margin-bottom": 20
        },
        "theme": {
            "gradient": "",
            "image": ""
        },
        "htmlBaseSize": 16,
        "hyperlink": {
            "font-size": 1,
            "line-height": "1_8",
            "text-color": "custom-color-5"
        }
    }
}
JSON
, true);
}
add_filter('nicepage_theme_settings', 'theme_app_settings');

function theme_analytics() {
?>
    <?php $GLOBALS['googleAnalyticsMarker'] = false; ?>
<?php
}
add_action('wp_head', 'theme_analytics', 0);


function theme_favicon() {
    $custom_favicon_id = get_theme_mod('custom_favicon');
    @list($favicon_src, ,) = wp_get_attachment_image_src($custom_favicon_id, 'full');
    if (!$favicon_src) {
        $favicon_src = "favicon1.ico";
        if ($favicon_src) {
            $favicon_src = get_template_directory_uri() . '/images/' . $favicon_src;
        }
    }

    if ($favicon_src) {
        echo "<link rel=\"icon\" href=\"$favicon_src\">";
    }
}
add_action('wp_head', 'theme_favicon');